@@ -16,6 +16,10 @@
 #'        design suggestions. Default is TRUE.
 #' @param include_telemetry Logical indicating whether to include telemetry
 #'        tracking and monitoring suggestions. Default is TRUE.
+#' @param telemetry_refs Optional character vector or named list specifying
+#'        specific telemetry reference points to include in validation steps.
+#'        If provided, these will be integrated into the telemetry tracking
+#'        recommendations with provenance information.
 #' @param include_empower_tools Logical indicating whether to include
 #'        context-aware empowerment tool suggestions. Default is TRUE.
 #'
@@ -23,43 +27,33 @@
 #'         stage.
 #'
 #' @examples
-#' structure_input <- bid_notice(
-#'   problem  = "Issue with dropdown menus",
-#'   evidence = "User testing indicated delays"
-#' ) |>
-#'   bid_interpret(
-#'     central_question = "How can we improve selection efficiency?",
+#' validate_result <- bid_interpret(
+#'     central_question = "How can we improve delivery efficiency?",
 #'     data_story = list(
-#'       hook = "Too many options",
-#'       context = "Excessive choices",
+#'       hook = "Too many delays",
+#'       context = "Excessive shipments",
 #'       tension = "User frustration",
-#'       resolution = "Simplify menu"
+#'       resolution = "Increase delivery channels"
 #'     )
+#'   ) |>
+#'   bid_notice(
+#'     problem  = "Issue with dropdown menus",
+#'     evidence = "User testing indicated delays"
+#'   ) |>
+#'   bid_anticipate(
+#'     bias_mitigations = list(
+#'       anchoring = "Provide reference points",
+#'       framing = "Use gain-framed messaging"
+#'     )
+#'   ) |>
+#'   bid_structure() |>
+#'   bid_validate(
+#'    include_exp_design = FALSE,
+#'    include_telemetry = TRUE,
+#'    include_empower_tools = TRUE
 #'   )
 #'
-#' structure_result <- bid_structure(
-#'   previous_stage = structure_input,
-#'   concepts       = c("Principle of Proximity", "Default Effect")
-#' )
-#'
-#' anticipate <- bid_anticipate(
-#'   previous_stage = structure_result,
-#'   bias_mitigations = list(
-#'     anchoring = "Provide reference points",
-#'     framing   = "Use gain-framed messaging"
-#'   )
-#' )
-#'
-#' bid_validate(
-#'   previous_stage = anticipate,
-#'   summary_panel = "Clear summary of key insights with action items",
-#'   collaboration = "Team annotation and sharing features",
-#'   next_steps = c(
-#'     "Conduct user testing with target audience",
-#'     "Implement accessibility improvements",
-#'     "Add mobile responsiveness"
-#'   )
-#' )
+#' summary(validate_result)
 #'
 #' @export
 bid_validate <- function(
@@ -69,6 +63,7 @@ bid_validate <- function(
     next_steps = NULL,
     include_exp_design = TRUE,
     include_telemetry = TRUE,
+    telemetry_refs = NULL,
     include_empower_tools = TRUE) {
   validate_required_params(previous_stage = previous_stage)
   validate_previous_stage(previous_stage, "Validate")
@@ -98,7 +93,8 @@ bid_validate <- function(
     next_steps <- generate_next_steps_suggestion(
       previous_stage,
       include_exp_design,
-      include_telemetry
+      include_telemetry,
+      telemetry_refs
     )
     cli::cli_alert_info("Suggested next steps:")
     for (step in next_steps) {
@@ -115,14 +111,16 @@ bid_validate <- function(
     previous_stage,
     include_exp_design,
     include_telemetry,
-    include_empower_tools
+    include_empower_tools,
+    telemetry_refs
   )
 
   # normalize previous stage to ensure field name consistency
   normalized_previous <- normalize_previous_stage(previous_stage)
   previous_info <- extract_previous_stage_info(normalized_previous)
 
-  result <- tibble::tibble(
+  # create result tibble
+  result_data <- tibble::tibble(
     stage = "Validate",
     summary_panel = summary_panel %||% NA_character_,
     collaboration = collaboration %||% NA_character_,
@@ -142,6 +140,22 @@ bid_validate <- function(
     timestamp = .now()
   )
 
+  # create comprehensive metadata using standardized helper
+  metadata <- get_stage_metadata(
+    5,
+    list(
+      has_summary_panel = !is.null(summary_panel),
+      has_collaboration = !is.null(collaboration),
+      next_steps_count = length(parse_next_steps(next_steps_formatted)),
+      include_exp_design = include_exp_design,
+      include_telemetry = include_telemetry,
+      include_empower_tools = include_empower_tools
+    )
+  )
+
+  # create and validate bid_stage object
+  result <- bid_stage("Validate", result_data, metadata)
+
   bid_message(
     "Stage 5 (Validate) completed.",
     paste0("Summary panel: ", truncate_text(summary_panel, 50)),
@@ -271,7 +285,8 @@ generate_collaboration_suggestion <- function(
 generate_next_steps_suggestion <- function(
   previous_stage,
   include_exp_design = TRUE,
-  include_telemetry = TRUE
+  include_telemetry = TRUE,
+  telemetry_refs = NULL
 ) {
   stage_name <- previous_stage$stage[1]
   next_steps <- character(0)
@@ -343,12 +358,21 @@ generate_next_steps_suggestion <- function(
 
   # add telemetry and monitoring recommendations if requested
   if (include_telemetry) {
-    next_steps <- c(
-      next_steps,
+    telemetry_steps <- c(
       "Implement telemetry tracking for user interactions and pain points",
       "Set up monitoring dashboards to track key performance indicators",
       "Plan post-launch telemetry analysis to validate design improvements"
     )
+    
+    # add specific telemetry references if provided
+    if (!is.null(telemetry_refs) && length(telemetry_refs) > 0) {
+      telemetry_steps <- c(
+        telemetry_steps,
+        .format_telemetry_refs_for_validation(telemetry_refs)
+      )
+    }
+    
+    next_steps <- c(next_steps, telemetry_steps)
   }
 
   next_steps <- c(
@@ -368,7 +392,8 @@ generate_validation_suggestions <- function(
     previous_stage,
     include_exp_design = TRUE,
     include_telemetry = TRUE,
-    include_empower_tools = TRUE) {
+    include_empower_tools = TRUE,
+    telemetry_refs = NULL) {
   suggestions <- character(0)
 
   if (!is.null(summary_panel) && nchar(summary_panel) > 0) {
@@ -529,6 +554,11 @@ extract_previous_stage_info <- function(previous_stage) {
       "concepts",
       NA_character_
     )
+    info$bias <- safe_column_access(
+      previous_stage,
+      "previous_bias",
+      NA_character_
+    )
     info$accessibility <- safe_column_access(
       previous_stage,
       "accessibility",
